@@ -17,14 +17,14 @@ from collections import OrderedDict
 import functools
 import re
 from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,17 +33,18 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.functions_v1.services.cloud_functions_service import pagers
-from google.cloud.functions_v1.types import functions
-from google.cloud.functions_v1.types import operations
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import CloudFunctionsServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import CloudFunctionsServiceGrpcAsyncIOTransport
+
+from google.cloud.functions_v1.services.cloud_functions_service import pagers
+from google.cloud.functions_v1.types import functions, operations
+
 from .client import CloudFunctionsServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, CloudFunctionsServiceTransport
+from .transports.grpc_asyncio import CloudFunctionsServiceGrpcAsyncIOTransport
 
 
 class CloudFunctionsServiceAsyncClient:
@@ -240,9 +241,9 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_list_functions():
+            async def sample_list_functions():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = functions_v1.ListFunctionsRequest(
@@ -252,7 +253,7 @@ class CloudFunctionsServiceAsyncClient:
                 page_result = client.list_functions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -336,9 +337,9 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_get_function():
+            async def sample_get_function():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = functions_v1.GetFunctionRequest(
@@ -346,7 +347,7 @@ class CloudFunctionsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_function(request=request)
+                response = await client.get_function(request=request)
 
                 # Handle the response
                 print(response)
@@ -374,7 +375,6 @@ class CloudFunctionsServiceAsyncClient:
                 contains user computation executed in
                 response to an event. It encapsulate
                 function and triggers configurations.
-                Next tag: 36
 
         """
         # Create or coerce a protobuf request object.
@@ -447,9 +447,9 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_create_function():
+            async def sample_create_function():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 function = functions_v1.CloudFunction()
@@ -465,7 +465,7 @@ class CloudFunctionsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -499,7 +499,7 @@ class CloudFunctionsServiceAsyncClient:
 
                 The result type for the operation will be :class:`google.cloud.functions_v1.types.CloudFunction` Describes a Cloud Function that contains user computation executed in
                    response to an event. It encapsulate function and
-                   triggers configurations. Next tag: 36
+                   triggers configurations.
 
         """
         # Create or coerce a protobuf request object.
@@ -569,9 +569,9 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_update_function():
+            async def sample_update_function():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 function = functions_v1.CloudFunction()
@@ -586,7 +586,7 @@ class CloudFunctionsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -614,7 +614,7 @@ class CloudFunctionsServiceAsyncClient:
 
                 The result type for the operation will be :class:`google.cloud.functions_v1.types.CloudFunction` Describes a Cloud Function that contains user computation executed in
                    response to an event. It encapsulate function and
-                   triggers configurations. Next tag: 36
+                   triggers configurations.
 
         """
         # Create or coerce a protobuf request object.
@@ -697,9 +697,9 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_delete_function():
+            async def sample_delete_function():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = functions_v1.DeleteFunctionRequest(
@@ -711,7 +711,7 @@ class CloudFunctionsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -831,9 +831,9 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_call_function():
+            async def sample_call_function():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = functions_v1.CallFunctionRequest(
@@ -842,7 +842,7 @@ class CloudFunctionsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.call_function(request=request)
+                response = await client.call_function(request=request)
 
                 # Handle the response
                 print(response)
@@ -960,16 +960,16 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_generate_upload_url():
+            async def sample_generate_upload_url():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = functions_v1.GenerateUploadUrlRequest(
                 )
 
                 # Make the request
-                response = client.generate_upload_url(request=request)
+                response = await client.generate_upload_url(request=request)
 
                 # Handle the response
                 print(response)
@@ -1035,16 +1035,16 @@ class CloudFunctionsServiceAsyncClient:
 
             from google.cloud import functions_v1
 
-            def sample_generate_download_url():
+            async def sample_generate_download_url():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = functions_v1.GenerateDownloadUrlRequest(
                 )
 
                 # Make the request
-                response = client.generate_download_url(request=request)
+                response = await client.generate_download_url(request=request)
 
                 # Handle the response
                 print(response)
@@ -1107,9 +1107,9 @@ class CloudFunctionsServiceAsyncClient:
             from google.cloud import functions_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_set_iam_policy():
+            async def sample_set_iam_policy():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iam_policy_pb2.SetIamPolicyRequest(
@@ -1117,7 +1117,7 @@ class CloudFunctionsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.set_iam_policy(request=request)
+                response = await client.set_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -1245,9 +1245,9 @@ class CloudFunctionsServiceAsyncClient:
             from google.cloud import functions_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_get_iam_policy():
+            async def sample_get_iam_policy():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iam_policy_pb2.GetIamPolicyRequest(
@@ -1255,7 +1255,7 @@ class CloudFunctionsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_iam_policy(request=request)
+                response = await client.get_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -1383,9 +1383,9 @@ class CloudFunctionsServiceAsyncClient:
             from google.cloud import functions_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_test_iam_permissions():
+            async def sample_test_iam_permissions():
                 # Create a client
-                client = functions_v1.CloudFunctionsServiceClient()
+                client = functions_v1.CloudFunctionsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = iam_policy_pb2.TestIamPermissionsRequest(
@@ -1394,7 +1394,7 @@ class CloudFunctionsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.test_iam_permissions(request=request)
+                response = await client.test_iam_permissions(request=request)
 
                 # Handle the response
                 print(response)
