@@ -17,17 +17,17 @@ from collections import OrderedDict
 import os
 import re
 from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,15 +36,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.functions_v1.services.cloud_functions_service import pagers
-from google.cloud.functions_v1.types import functions
-from google.cloud.functions_v1.types import operations
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import CloudFunctionsServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.functions_v1.services.cloud_functions_service import pagers
+from google.cloud.functions_v1.types import functions, operations
+
+from .transports.base import DEFAULT_CLIENT_INFO, CloudFunctionsServiceTransport
 from .transports.grpc import CloudFunctionsServiceGrpcTransport
 from .transports.grpc_asyncio import CloudFunctionsServiceGrpcAsyncIOTransport
 
@@ -482,6 +483,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_functions(
@@ -624,7 +626,6 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
                 contains user computation executed in
                 response to an event. It encapsulate
                 function and triggers configurations.
-                Next tag: 36
 
         """
         # Create or coerce a protobuf request object.
@@ -739,7 +740,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
                 The result type for the operation will be :class:`google.cloud.functions_v1.types.CloudFunction` Describes a Cloud Function that contains user computation executed in
                    response to an event. It encapsulate function and
-                   triggers configurations. Next tag: 36
+                   triggers configurations.
 
         """
         # Create or coerce a protobuf request object.
@@ -854,7 +855,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
                 The result type for the operation will be :class:`google.cloud.functions_v1.types.CloudFunction` Describes a Cloud Function that contains user computation executed in
                    response to an event. It encapsulate function and
-                   triggers configurations. Next tag: 36
+                   triggers configurations.
 
         """
         # Create or coerce a protobuf request object.
