@@ -43,7 +43,7 @@ class functionsCallTransformer(cst.CSTTransformer):
         'create_function': ('location', 'function', ),
         'delete_function': ('name', ),
         'generate_download_url': ('name', 'version_id', ),
-        'generate_upload_url': ('parent', ),
+        'generate_upload_url': ('parent', 'kms_key_name', ),
         'get_function': ('name', ),
         'get_iam_policy': ('resource', 'options', ),
         'list_functions': ('parent', 'page_size', 'page_token', ),
